package com.ruoyi.system.service.impl;

import com.ruoyi.common.core.exception.ServiceException;
import com.ruoyi.common.core.utils.StringUtils;
import java.util.List;
import com.ruoyi.system.domain.SysPost;
import com.ruoyi.system.mapper.SysUserPostMapper;
import org.springframework.beans.factory.annotation.Autowired;
import com.ruoyi.system.mapper.SysPostMapper;
import org.springframework.stereotype.Service;
import com.ruoyi.system.service.ISysPostService;

@Service
public class SysPostServiceImpl implements ISysPostService
{
    @Autowired
    private SysPostMapper postMapper;
    @Autowired
    private SysUserPostMapper userPostMapper;
    
    public List<SysPost> selectPostList(final SysPost post) {
        return this.postMapper.selectPostList(post);
    }
    
    public List<SysPost> selectPostAll() {
        return this.postMapper.selectPostAll();
    }
    
    public SysPost selectPostById(final Long postId) {
        return this.postMapper.selectPostById(postId);
    }
    
    public List<Long> selectPostListByUserId(final Long userId) {
        return this.postMapper.selectPostListByUserId(userId);
    }
    
    public boolean checkPostNameUnique(final SysPost post) {
        final Long postId = StringUtils.isNull((Object)post.getPostId()) ? -1L : post.getPostId();
        final SysPost info = this.postMapper.checkPostNameUnique(post.getPostName());
        return !StringUtils.isNotNull((Object)info) || info.getPostId() == (long)postId;
    }
    
    public boolean checkPostCodeUnique(final SysPost post) {
        final Long postId = StringUtils.isNull((Object)post.getPostId()) ? -1L : post.getPostId();
        final SysPost info = this.postMapper.checkPostCodeUnique(post.getPostCode());
        return !StringUtils.isNotNull((Object)info) || info.getPostId() == (long)postId;
    }
    
    public int countUserPostById(final Long postId) {
        return this.userPostMapper.countUserPostById(postId);
    }
    
    public int deletePostById(final Long postId) {
        return this.postMapper.deletePostById(postId);
    }
    
    public int deletePostByIds(final Long[] postIds) {
        for (final Long postId : postIds) {
            final SysPost post = this.selectPostById(postId);
            if (this.countUserPostById(postId) > 0) {
                throw new ServiceException(String.format("%1$s已分配,不能删除", post.getPostName()));
            }
        }
        return this.postMapper.deletePostByIds(postIds);
    }
    
    public int insertPost(final SysPost post) {
        return this.postMapper.insertPost(post);
    }
    
    public int updatePost(final SysPost post) {
        return this.postMapper.updatePost(post);
    }
}
